==> spotify_openapi-0.0.0.tar.gz: test/artist_object_test.dart <==
import 'package:test/test.dart';
import 'package:spotify_openapi/spotify_openapi.dart';

// tests for ArtistObject
void main() {
  final ArtistObject? instance = /* ArtistObject(...) */ null;
  // TODO add properties to the entity

  group(ArtistObject, () {
    // ArtistObjectExternalUrls externalUrls
    test('to test the property `externalUrls`', () async {
      // TODO
    });

    // ArtistObjectFollowers followers
    test('to test the property `followers`', () async {
      // TODO
    });

    // A list of the genres the artist is associated with. If not yet classified, the array is empty. 
    // List<String> genres
    test('to test the property `genres`', () async {
      // TODO
    });

    // A link to the Web API endpoint providing full details of the artist. 
    // String href
    test('to test the property `href`', () async {
      // TODO
    });

    // The [Spotify ID](/documentation/web-api/concepts/spotify-uris-ids) for the artist. 
    // String id
    test('to test the property `id`', () async {
      // TODO
    });

    // Images of the artist in various sizes, widest first. 
    // List<ImageObject> images
    test('to test the property `images`', () async {
      // TODO
    });

    // The name of the artist. 
    // String name
    test('to test the property `name`', () async {
      // TODO
    });

    // The popularity of the artist. The value will be between 0 and 100, with 100 being the most popular. The artist's popularity is calculated from the popularity of all the artist's tracks. 
    // int popularity
    test('to test the property `popularity`', () async {
      // TODO
    });

    // The object type. 
    // String type
    test('to test the property `type`', () async {
      // TODO
    });

    // The [Spotify URI](/documentation/web-api/concepts/spotify-uris-ids) for the artist. 
    // String uri
    test('to test the property `uri`', () async {
      // TODO
    });

  });
}

==> spotify_openapi-0.0.1.tar.gz: test/artist_object_test.dart <==
import 'package:test/test.dart';
import 'package:spotify_openapi/spotify_openapi.dart';

// tests for ArtistObject
void main() {
  final instance = ArtistObjectBuilder();
  // TODO add properties to the builder and call build()

  group(ArtistObject, () {
    // ArtistObjectExternalUrls externalUrls
    test('to test the property `externalUrls`', () async {
      // TODO
    });

    // ArtistObjectFollowers followers
    test('to test the property `followers`', () async {
      // TODO
    });

    // A list of the genres the artist is associated with. If not yet classified, the array is empty. 
    // BuiltList<String> genres
    test('to test the property `genres`', () async {
      // TODO
    });

    // A link to the Web API endpoint providing full details of the artist. 
    // String href
    test('to test the property `href`', () async {
      // TODO
    });

    // The [Spotify ID](/documentation/web-api/concepts/spotify-uris-ids) for the artist. 
    // String id
    test('to test the property `id`', () async {
      // TODO
    });

    // Images of the artist in various sizes, widest first. 
    // BuiltList<ImageObject> images
    test('to test the property `images`', () async {
      // TODO
    });

    // The name of the artist. 
    // String name
    test('to test the property `name`', () async {
      // TODO
    });

    // The popularity of the artist. The value will be between 0 and 100, with 100 being the most popular. The artist's popularity is calculated from the popularity of all the artist's tracks. 
    // int popularity
    test('to test the property `popularity`', () async {
      // TODO
    });

    // The object type. 
    // String type
    test('to test the property `type`', () async {
      // TODO
    });

    // The [Spotify URI](/documentation/web-api/concepts/spotify-uris-ids) for the artist. 
    // String uri
    test('to test the property `uri`', () async {
      // TODO
    });

  });
}
